.. Camelot documentation master file, created by
   sphinx-quickstart on Thu Jun 11 21:14:38 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _camelotdoc-index:

Welcome to Camelot's documentation!
===================================

:Release: |version|
:Date: |today|
   
.. toctree::
   :maxdepth: 1
   
   news.rst
   
Contents:

.. toctree::
   :maxdepth: 2

   tutorial/index.rst
   doc/index.rst
   advanced/index.rst

Support
=======

Commercial support
------------------

+-----------------------------------+-------------------------+
| Conceptive Engineering            | L Van Bauwelstraat 16   |
+-----------------------------------+-------------------------+
| project-camelot@conceptive.be     | 2222 Heist-op-den-Berg  |
+-----------------------------------+-------------------------+
| http://www.conceptive.be          | Belgium                 |
+-----------------------------------+-------------------------+
| Fax : +32 3 303 64 41             | VAT BE 0878 169 209     |
+-----------------------------------+-------------------------+

Indices and tables:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Others:

.. toctree::
   :maxdepth: 2

   Complete Table of Contents <contents.rst>
   license.rst
   copyright.rst
